import { consoleFunctions } from "./console.js";
import { readFileSync } from "node:fs";
import { MongoClient } from "mongodb";
import dotenv from "dotenv";
import { join } from "node:path";

import { __dirname } from "../common.js";

dotenv.config();

export const appFunctions = {
  dbClient: new MongoClient(process.env.NODE_ENV == "PRODUCTION" ? process.env.MONGO_CONNECTION_STRING : process.env.MONGO_CONNECTION_STRING_DEV),
  async appInit(prod, port) {
    console.clear();

    if (!this.dbClient || !this.dbClient.db)
      await this.dbClient.connect();
    const collection = this.dbClient.db("HTTP-Proxy").collection("Routes");
    const documents = await collection.find().toArray();
    
    const routes = [];

    documents.forEach((document, index) => {
      routes.push(`${index + 1}. From: ${document.url}, to ${document.server}.`);
    });

    await this.dbClient.close();

    console.log(consoleFunctions.init(prod, port, routes));
    
  },
  findErrorRoute: (routes) => {
    console.log(routes);
  },
  messageFromCode: (code) => {
    const data = JSON.parse(readFileSync(join(__dirname, "data", "messages.json")));
    const codeClass = code.toString().split("").shift().padEnd("3", 0);
    return data[codeClass][code].replace("\n", "<br>");
  },
  sendError: async (code, res) => {
    console.log(code)
    if (code.toString().startsWith("/")) code = code.slice(0, 1);
    console.log(code)
    if (!code.toString().startsWith(5)) return res.redirect(`https://err.backwardshosting.ca/${code}`);
    const message = appFunctions.messageFromCode(code);
    res.render("index", { code, message });
  }
}