import { join } from "node:path";
import express from"express";

import { __dirname } from "./common.js";
import { appFunctions } from "./functions/app.js";
import { consoleFunctions } from "./functions/console.js";

const app = express();
const prod = process.env.NODE_ENV === "PRODUCTION";

const port = (prod) ? 80 : 2025; // Port 80 (HTTP) or 2025 in development.

app.listen(port, () => appFunctions.appInit(prod, port)); // Redirect console messages to dedicated consoleFunctions module.

app.set('view engine', 'ejs');
app.set('views', join(__dirname, "view"));


app.use(async function (req, res) {
  consoleFunctions.log("RECEIVED HTTP REQUEST");
  consoleFunctions.log("GETTING ROUTES FROM DATABASE");
  await appFunctions.dbClient.connect();
  const collection = appFunctions.dbClient.db("HTTP-Proxy").collection("Routes");
  const routes = await collection.find().toArray();
  await appFunctions.dbClient.close();

  consoleFunctions.log(`REQUESTED: ${req.headers.host}`);
  const errorRoutes = routes.filter(route => route.url === req.headers.host && route.server === "ERROR");
  if (errorRoutes.length > 0) {
    appFunctions.sendError(req.url, res);
  }


  if (!routes) {
    appFunctions.sendError(500, res);
  }

  appFunctions.findErrorRoute(routes);
  appFunctions.sendError(501, res);

  
});